## system-slash
[![Build Status](https://travis-ci.org/sujitmandal/system-slash.svg?branch=main)](https://travis-ci.org/sujitmandal/system-slash) [![GitHub license](https://img.shields.io/github/license/sujitmandal/system-slash)](https://github.com/sujitmandal/system-slash/blob/main/LICENSE) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/system-slash) ![PyPI - Wheel](https://img.shields.io/pypi/wheel/system-slash) ![PyPI](https://img.shields.io/pypi/v/system-slash)


[![Downloads](https://pepy.tech/badge/system-slash)](https://pepy.tech/project/system-slash)


It will find operating system and then generate slash as per system required.


## Package Installation :

```
pip install system-slash
```
[Package Link](https://pypi.org/project/system-slash/)


## How to import the module:
```
from SystemSlash.SystemSlash import slash

system = slash()

print(system)
```



## License:
```
MIT Licensed
```

## Author:
```
Sujit Mandal
```

[GitHub](https://github.com/sujitmandal)

[PyPi](https://pypi.org/user/sujitmandal/)

[LinkedIn](https://www.linkedin.com/in/sujit-mandal-91215013a/)